@@ -25,6 +25,9 @@ class AdamApiError( Exception ):
     """Base class for exceptions on the adamapi module."""
     pass
 
+class AdamApiMessage( Exception ):
+    """Base class for adamapi mesage"""
+    pass
 
 from . import authorization
 from . import datasets
